@@ -18,13 +18,16 @@
 #                                                                         # 
 ###########################################################################
 
-.onAttach <- function(lib, pkg){
+.onAttach <- function(lib, pkg)
+{
   info <- packageDescription("hergm")
   packageStartupMessage(
-    paste('\nhergm: version ', info$Version, ', created on ', info$Date, '\n',
+  paste('\nhergm: version ', info$Version, ', created on ', info$Date, '\n',
           "Copyright (c) 2009, Michael Schweinberger, Rice University\n", 
           "                    Mark S. Handcock, University of California - Los Angeles\n",
+          "                    Pamela Luna, Rice University\n",
           "To start hergm: enter help(package=\"hergm\")\n",
           'For license and citation information type citation("hergm").\n', sep="")
  )
 }
+
